@@ -24,11 +24,11 @@ http://code.google.com/p/pyentropy
 """
 
 __author__ = 'Robin Ince'
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 
 from systems import DiscreteSystem, SortedDiscreteSystem
 from utils import (prob, decimalise, nsb_entropy, quantise,
-                             dec2base, base2dec)
+                             dec2base, base2dec, quantise_discrete)
 
 from numpy.testing import Tester
 test = Tester().test
